# -*- coding: utf-8 -*-
##############################################################################
#
# Copyright (c) 2010 Nexedi SA and Contributors. All Rights Reserved.
# Copyright (c) 2006-2008 Zope Corporation and Contributors.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################

import os
from string import Template
import logging
from time import sleep
import subprocess
import zc.buildout
import zc.buildout.easy_install
import zc.recipe.egg
import pkg_resources

class WithMinusTemplate(Template):
  idpattern = '[_a-z][-_a-z0-9]*'

class Recipe(object):
  def __init__(self, buildout, name, options):
    self.buildout, self.options, self.name = buildout, options, name
    self.egg = zc.recipe.egg.Egg(buildout, options['recipe'], options)
    self.logger=logging.getLogger(self.name)

    options['location'] = os.path.join(
        buildout['buildout']['parts-directory'],
        self.name)

    options.setdefault('sphinx_bin_directory',
                       buildout['buildout']['bin-directory'])


  def install_script(self, script_name):
    """ Create default scripts
    """
    options = self.options
    sphinx_software_bin = options.get("sphinx_software_bin")
    sphinx_conf_file = options.get("sphinx_conf_file")
    requirements, ws = self.egg.working_set(['erp5.recipe.sphinxserver'])
    scripts = zc.buildout.easy_install.scripts(
        [(script_name,'erp5.recipe.sphinxserver.ctl', 'main')],
        ws, options['executable'], options.get("sphinx_bin_directory"),
        arguments = ("\n        ['%s/%s' ,"
                     "\n        '-c', '%s'] "
                     "\n        + sys.argv[1:]" % (sphinx_software_bin,
                                                   script_name,
                                                   sphinx_conf_file)))

  def build_configuration_file(self):
    template_file = self.options.get('sphinx_conf_template', '').strip()
    if template_file:
      template_input_data = file(template_file).read()
    else:
      template_input_data = pkg_resources.resource_stream(__name__,
          'sphinx.conf.in').read()

    file(self.options['sphinx_conf_file'], 'w').write(
      WithMinusTemplate(template_input_data).safe_substitute(
        self.options.copy()))

  def install(self):
    options = self.options
    self.build_configuration_file()
    data_directory = options.get('sphinx_data_directory')
    if not os.path.exists(data_directory):
      os.mkdir(data_directory)
    log_directory = options.get('sphinx_log_directory')
    if not os.path.exists(log_directory):
      os.mkdir(log_directory)
    self.install_script('indexer')
    self.install_script('indextool')
    self.install_script('search')
    self.install_script('searchd')
    self.install_script('spelldump')
    return []

  update = install
